timeintervaltools.TimeInterval
==============================

.. abjad-lineage:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval

.. autoclass:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.bounds
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.center
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.clear
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.duration
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.get
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.get_overlap_with_interval
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_contained_by_interval
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_container_of_interval
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_overlapped_by_interval
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_tangent_to_interval
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.items
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.iteritems
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.iterkeys
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.itervalues
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.keys
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.pop
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.popitem
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.quantize_to_rational
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.scale_by_rational
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.scale_to_rational
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.setdefault
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.shift_by_rational
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.shift_to_rational
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.signature
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.split_at_rationals
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.start_offset
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.stop_offset
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.storage_format
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.update
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.values
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__contains__
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__delitem__
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__eq__
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__getitem__
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__hash__
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__iter__
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__len__
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__ne__
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__nonzero__
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__repr__
      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__setitem__

Bases
-----

- :py:class:`timeintervaltools.TimeIntervalMixin <abjad.tools.timeintervaltools.TimeIntervalMixin.TimeIntervalMixin.TimeIntervalMixin>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`_abcoll.MutableMapping <_abcoll.MutableMapping>`

- :py:class:`_abcoll.Mapping <_abcoll.Mapping>`

- :py:class:`_abcoll.Sized <_abcoll.Sized>`

- :py:class:`_abcoll.Iterable <_abcoll.Iterable>`

- :py:class:`_abcoll.Container <_abcoll.Container>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.bounds
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.center
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.duration
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.signature
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.start_offset
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.clear
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.get
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.get_overlap_with_interval
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_contained_by_interval
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_container_of_interval
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_overlapped_by_interval
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_tangent_to_interval
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.items
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.iteritems
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.iterkeys
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.itervalues
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.keys
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.pop
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.popitem
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.quantize_to_rational
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.scale_by_rational
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.scale_to_rational
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.setdefault
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.shift_by_rational
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.shift_to_rational
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.split_at_rationals
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.update
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.values
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__contains__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__delitem__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__eq__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__getitem__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__hash__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__iter__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__len__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__ne__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__nonzero__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__repr__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__setitem__
   :noindex:
